Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: chrome/browser/metrics/chrome_metrics_service_client.h

Issue 2136423003: Merge M52: Add AntiVirus information to the system profile. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2743
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/metrics/chrome_metrics_service_client.h
diff --git a/chrome/browser/metrics/chrome_metrics_service_client.h b/chrome/browser/metrics/chrome_metrics_service_client.h
index b340c84bb2ce773c96ac50735a4184e67cca4051..a92acf7f6326ae5e66f4b7b7b283009a6c7e8f43 100644
--- a/chrome/browser/metrics/chrome_metrics_service_client.h
+++ b/chrome/browser/metrics/chrome_metrics_service_client.h
@@ -22,6 +22,7 @@
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
+class AntiVirusMetricsProvider;
class ChromeOSMetricsProvider;
class GoogleUpdateMetricsProviderWin;
class PluginMetricsProvider;
@@ -103,9 +104,13 @@ class ChromeMetricsServiceClient
void OnInitTaskGotPluginInfo();
// Called after GoogleUpdate init task has been completed that continues the
// init task by loading drive metrics.
void OnInitTaskGotGoogleUpdateData();
+ // Called after AntiVirus init task has been completed that continues the
+ // init task by loading drive metrics.
+ void OnInitTaskGotAntiVirusData();
+
// Called after the drive metrics init task has been completed that continues
// the init task by loading profiler data.
void OnInitTaskGotDriveMetrics();
@@ -190,6 +195,10 @@ class ChromeMetricsServiceClient
// The GoogleUpdateMetricsProviderWin instance that was registered with
// MetricsService. Has the same lifetime as |metrics_service_|.
GoogleUpdateMetricsProviderWin* google_update_metrics_provider_;
+
+ // The AntiVirusMetricsProvider instance that was registered with
+ // MetricsService. Has the same lifetime as |metrics_service_|.
+ AntiVirusMetricsProvider* antivirus_metrics_provider_;
#endif
// The DriveMetricsProvider instance that was registered with MetricsService.
@@ -103,9 +104,13 @@ class ChromeMetricsServiceClient
void OnInitTaskGotPluginInfo();
// Called after GoogleUpdate init task has been completed that continues the
- // init task by loading drive metrics.
+ // init task by loading AntiVirus metrics.
void OnInitTaskGotGoogleUpdateData();

Powered by Google App Engine
This is Rietveld 408576698